@@ -131,14 +131,12 @@ DiseasystoreBase <- R6::R6Class(
       feature_loader <- purrr::pluck(ds_map, feature)
 
       # Determine where these features are stored
-      target_table <- paste(c(self %.% target_schema, feature_loader), collapse = ".")
+      target_table <- paste(self %.% target_schema, feature_loader, sep = ".")
 
 
       # Create log table
-      suppressMessages(
-        SCDB::create_logs_if_missing(log_table = paste(c(self %.% target_schema, "logs"), collapse = "."),
-                                     conn = self %.% target_conn)
-      )
+      SCDB::create_logs_if_missing(log_table = paste(self %.% target_schema, "logs", sep = "."),
+                                   conn = self %.% target_conn)
 
       # Determine dates that need computation
       ds_missing_ranges <- private$determine_new_ranges(target_table = target_table,
@@ -190,9 +188,10 @@ DiseasystoreBase <- R6::R6Class(
                                             slice_ts = slice_ts, source_conn = self %.% source_conn))
 
           # Check it table is copied to target DB
-          if (!inherits(ds_feature, "tbl_dbi") ||
-                !identical(self %.% source_conn, self %.% target_conn)) {
-            ds_feature <- dplyr::copy_to(self %.% target_conn, ds_feature, "ds_tmp", overwrite = TRUE)
+          if (!inherits(ds_feature, "tbl_dbi") || !identical(self %.% source_conn, self %.% target_conn)) {
+            ds_feature <- ds_feature |>
+              dplyr::copy_to(self %.% target_conn, df = _,
+                             name = paste("ds", feature_loader, Sys.getpid(), sep = "_"), overwrite = TRUE)
           }
 
           # Add the existing computed data for given slice_ts
@@ -214,18 +213,18 @@ DiseasystoreBase <- R6::R6Class(
 
           # Configure the Logger
           log_table_id <- SCDB::id(
-            paste(c(self %.% target_schema, "logs"), collapse = "."),
+            paste(self %.% target_schema, "logs", sep = "."),
             self %.% target_conn
           )
 
-          logger <- suppressMessages(SCDB::Logger$new(
+          logger <- SCDB::Logger$new(
             output_to_console = FALSE,
             log_table_id = log_table_id,
             log_conn = self %.% target_conn
-          ))
+          )
 
           # Commit to DB
-          suppressMessages(SCDB::update_snapshot(
+          SCDB::update_snapshot(
             .data = ds_updated_feature,
             conn = self %.% target_conn,
             db_table = target_table,
@@ -233,7 +232,7 @@ DiseasystoreBase <- R6::R6Class(
             message = glue::glue("ds-range: {start_date} - {end_date}"),
             logger = logger,
             enforce_chronological_order = FALSE
-          ))
+          )
         })
 
         # Release the lock on the table
@@ -253,13 +252,15 @@ DiseasystoreBase <- R6::R6Class(
 
       # We need to slice to the period of interest.
       # to ensure proper conversion of variables, we first copy the limits over and then do an inner_join
-      out <- dplyr::inner_join(out,
-                               data.frame(valid_from = start_date, valid_until = end_date) |>
-                                 dplyr::copy_to(self %.% target_conn, df = _, "ds_tmp", overwrite = TRUE),
+      validities <- data.frame(valid_from = start_date, valid_until = end_date) |>
+        dplyr::copy_to(self %.% target_conn, df = _, name = paste0("ds_validities_", Sys.getpid()), overwrite = TRUE)
+
+      out <- dplyr::inner_join(out, validities,
                                sql_on = '"LHS"."valid_from" <= "RHS"."valid_until" AND
                                          ("LHS"."valid_until" > "RHS"."valid_from" OR "LHS"."valid_until" IS NULL)',
                                suffix = c("", ".p")) |>
-        dplyr::select(!c("valid_from.p", "valid_until.p"))
+        dplyr::select(!c("valid_from.p", "valid_until.p")) |>
+        dplyr::compute()
 
       return(out)
     },
@@ -304,7 +305,7 @@ DiseasystoreBase <- R6::R6Class(
 
       # We start by copying the study_dates to the conn to ensure SQLite compatibility
       study_dates <- data.frame(valid_from = start_date, valid_until = base::as.Date(end_date + lubridate::days(1))) |>
-        dplyr::copy_to(self %.% target_conn, df = _, name = "ds_tmp", overwrite = TRUE)
+        dplyr::copy_to(self %.% target_conn, df = _, name = paste0("ds_study_dates_", Sys.getpid()), overwrite = TRUE)
 
       # Determine which features are affected by a stratification
       if (!is.null(stratification)) {
@@ -392,8 +393,7 @@ DiseasystoreBase <- R6::R6Class(
       # Merge and prepare for counting
       out <- truncate_interlace(observable_data, stratification_data) |>
         private$key_join_filter(stratification_features, start_date, end_date) |>
-        dplyr::compute() |>
-        dplyr::group_by(!!!stratification)
+        dplyr::compute()
 
       # Retrieve the aggregators (and ensure they work together)
       key_join_aggregators <- c(purrr::pluck(private, purrr::pluck(ds_map, observable)) %.% key_join,
@@ -408,6 +408,7 @@ DiseasystoreBase <- R6::R6Class(
 
       # Add the new valid counts
       t_add <- out |>
+        dplyr::group_by(!!!stratification) |>
         dplyr::group_by(date = valid_from, .add = TRUE) |>
         key_join_aggregator(observable) |>
         dplyr::rename(n_add = n) |>
@@ -415,6 +416,7 @@ DiseasystoreBase <- R6::R6Class(
 
       # Add the new invalid counts
       t_remove <- out |>
+        dplyr::group_by(!!!stratification) |>
         dplyr::group_by(date = valid_until, .add = TRUE) |>
         key_join_aggregator(observable) |>
         dplyr::rename(n_remove = n) |>
@@ -431,12 +433,18 @@ DiseasystoreBase <- R6::R6Class(
           dplyr::compute()
       } else {
         all_combinations <- all_dates
+
+        # Copy if needed
+        if (is.null(stratification)) {
+          all_combinations <- all_combinations |>
+            dplyr::copy_to(self %.% target_conn, df = _,
+                           name = paste0("ds_all_combinations_", Sys.getpid()), overwrite = TRUE)
+        }
       }
 
       # Aggregate across dates
       data <- t_add |>
-        dplyr::right_join(all_combinations, by = c("date", stratification_names), na_matches = "na",
-                          copy = is.null(stratification)) |>
+        dplyr::right_join(all_combinations, by = c("date", stratification_names), na_matches = "na") |>
         dplyr::left_join(t_remove,  by = c("date", stratification_names), na_matches = "na") |>
         tidyr::replace_na(list(n_add = 0, n_remove = 0)) |>
         dplyr::group_by(dplyr::across(tidyselect::all_of(stratification_names))) |>
@@ -450,6 +458,12 @@ DiseasystoreBase <- R6::R6Class(
       data <- data |>
         dplyr::mutate(date = as.Date(date))
 
+
+      # Clean up
+      DBI::dbRemoveTable(self %.% target_conn, SCDB::id(out))
+      DBI::dbRemoveTable(self %.% target_conn, SCDB::id(t_add))
+      DBI::dbRemoveTable(self %.% target_conn, SCDB::id(t_remove))
+
       return(data)
     }
   ),
@@ -581,7 +595,7 @@ DiseasystoreBase <- R6::R6Class(
 
       # Get a list of the logs for the target_table on the slice_ts
       logs <- dplyr::tbl(self %.% target_conn,
-                         SCDB::id(paste(c(self %.% target_schema, "logs"), collapse = "."), self %.% target_conn),
+                         SCDB::id(paste(self %.% target_schema, "logs", sep = "."), self %.% target_conn),
                          check_from = FALSE) |>
         dplyr::collect() |>
         tidyr::unite("target_table", "schema", "table", sep = ".", na.rm = TRUE) |>
